==> kyman-0.1.15.tar.gz: kyman-0.1.15/setup.py <==
#!/usr/bin/env python3

"""The setup script."""

from setuptools import setup

from kyman import __author__, __email__, __version__

with open("README.md", encoding="utf-8") as readme_file:
    readme = readme_file.read()

with open("HISTORY.md", encoding="utf-8") as history_file:
    history = history_file.read()

setup(
    name="kyman",
    version=__version__,
    description="Python Tools for Kafka object management",
    long_description=readme + "\n\n" + history,
    long_description_content_type="text/markdown",
    url="https://github.com/UltimateSoftware/kyman.git",
    author=__author__,
    author_email=__email__,
    python_requires=">=3.7",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Operating System :: OS Independent",
    ],
    keywords="kyman kafka topic acls management",
    packages=["kyman"],
    install_requires=["requests", "pyyaml", "python-dotenv", "jsonformatter"],
    extras_require={
        "dev": [
            "isort",
            "pytest",
            "pytest-mock",
            "pytest-cov",
            "flake8",
            "mypy",
            "black",
            "pipenv-setup",
            "sphinx",
            "watchdog",
            "argh",
            "twine",
            "rstcheck",
        ]
    },
    license="Apache Software License 2.0",
    entry_points={"console_scripts": ["kyman=kyman.cli:main"]},
)

==> kyman-0.2.1.tar.gz: kyman-0.2.1/setup.py <==
#!/usr/bin/env python3

"""The setup script."""

from setuptools import setup

from kyman import __author__, __email__, __version__

with open("README.md", encoding="utf-8") as readme_file:
    readme = readme_file.read()

setup(
    name="kyman",
    version=__version__,
    description="Python Tools for Kafka object management",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/UltimateSoftware/kyman.git",
    author=__author__,
    author_email=__email__,
    python_requires=">=3.7",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Operating System :: OS Independent",
    ],
    keywords="kyman kafka topic acls management",
    packages=["kyman"],
    install_requires=["requests", "pyyaml", "python-dotenv", "jsonformatter"],
    extras_require={
        "dev": [
            "isort",
            "pytest",
            "pytest-mock",
            "pytest-cov",
            "flake8",
            "mypy",
            "black",
            "pipenv-setup",
            "sphinx",
            "watchdog",
            "argh",
            "twine",
            "rstcheck",
        ]
    },
    license="Apache Software License 2.0",
    entry_points={"console_scripts": ["kyman=kyman.cli:main"]},
)
